@@ -3,7 +3,7 @@
                            Coda File System
                               Release 5
 
-          Copyright (c) 1987-1999 Carnegie Mellon University
+          Copyright (c) 1987-2008 Carnegie Mellon University
                   Additional copyrights listed below
 
 This  code  is  distributed "AS IS" without warranty of any kind under
@@ -548,6 +548,7 @@ void rpc2_ClockTick(void *);
 /* rpc2_SocketListener packet handlers */
 void SL_RegisterHandler(unsigned int proto, void (*func)(RPC2_PacketBuffer *));
 void rpc2_HandlePacket(RPC2_PacketBuffer *pb);
+void RPC2_DispatchProcess(void);
 
 /* Packet timestamp creation */
 unsigned int rpc2_TVTOTS(const struct timeval *tv);
@@ -617,6 +618,8 @@ void rpc2_printaddrinfo(const struct RPC2_addrinfo *ai, FILE *f);
 void rpc2_splitaddrinfo(RPC2_HostIdent *Host, RPC2_PortIdent *Port,
 			const struct RPC2_addrinfo *ai);
 void rpc2_simplifyHost(RPC2_HostIdent *Host, RPC2_PortIdent *Port);
+void rpc2_formataddrinfo(const struct RPC2_addrinfo *ai, char *buf,
+			 size_t buflen, int use_canonname);
 
 
 /*--------------- Useful definitions that used to be in potpourri.h or util.h ---------------*/
