@@ -3,7 +3,7 @@
                            Coda File System
                               Release 5
 
-          Copyright (c) 1987-1999 Carnegie Mellon University
+          Copyright (c) 1987-2008 Carnegie Mellon University
                   Additional copyrights listed below
 
 This  code  is  distributed "AS IS" without warranty of any kind under
@@ -61,12 +61,11 @@ Pittsburgh, PA.
 #include <unistd.h>
 #include "rpc2.private.h"
 #include <rpc2/se.h>
-#include "sftp.h"
+#include <rpc2/sftp.h>
 
 /* Globals: see sftp.h for descriptions; set by SFTP_Activate(), via SFTP_SetDefaults() */
 long SFTP_PacketSize;
 long SFTP_WindowSize;
-long SFTP_RetryCount;
 long SFTP_EnforceQuota;
 long SFTP_SendAhead;
 long SFTP_AckPoint;
@@ -445,8 +444,9 @@ int sftp_WriteStrategy(struct SFTP_Entry *sEntry)
     if (iovlen == 0)
 	return(0);  /* 0-length initial run of packets */
 
-    if (!(bytesnow == sftp_vfwritev(sEntry, iovarray, iovlen))) {
+    if (bytesnow != sftp_vfwritev(sEntry, iovarray, iovlen)) {
 	sftp_SetError(sEntry, DISKERROR);	/* probably disk full */
+	say(1, SFTP_DebugLevel, "WriteStrategy: write failed\n");
 	return(-1);
     }
 
@@ -738,9 +738,7 @@ int sftp_SendStrategy(struct SFTP_Entry *sEntry)
     {
 	/* Window is closed: try to send any worried packets */
 	sftp_windowfulls++;
-	if (worried && ResendWorried(sEntry) < 0)
-	    return(-1);
-	return 0;
+	return ResendWorried(sEntry);
     }
 
     /* Window is open: be more ambitious */
@@ -775,7 +773,7 @@ static int CheckWorried(struct SFTP_Entry *sEntry)
     struct timeval tv;
 
     ce = rpc2_GetConn(sEntry->LocalHandle);
-    if (!ce) {
+    if (!ce || sEntry->HitEOF) {
 	sEntry->SendWorriedLimit = sEntry->SendAckLimit;
 	return 1;
     }
@@ -843,11 +841,11 @@ static int ResendWorried(struct SFTP_Entry *sEntry)
 		acked = 1;
 	    }
 	    if (i == sEntry->SendLastContig+1)
-	        {/* first packet */
+	    {/* first packet */
 		pb->Header.SEFlags = ntohl(pb->Header.SEFlags);
 		pb->Header.SEFlags |= SFTP_FIRST;
 		pb->Header.SEFlags = htonl(pb->Header.SEFlags);
-	        }
+	    }
 	    pb->Header.Flags |= RPC2_RETRY;
 
 	    sftp_Sent.Datas++;
@@ -870,8 +868,8 @@ static int ResendWorried(struct SFTP_Entry *sEntry)
 #endif
 
 	    say(/*9*/4, SFTP_DebugLevel, "Worried S-%lu [%lu] {%lu}\n",
-		    (unsigned long)ntohl(pb->Header.SeqNumber), 
-		    (unsigned long)ntohl(pb->Header.TimeStamp), 
+		    (unsigned long)ntohl(pb->Header.SeqNumber),
+		    (unsigned long)ntohl(pb->Header.TimeStamp),
 		    (unsigned long)ntohl(pb->Header.TimeEcho));
 	    sftp_XmitPacket(sEntry, pb, 0);
 	}
