@@ -64,7 +64,7 @@ Pittsburgh, PA.
 #include <unistd.h>
 #include "rpc2.private.h"
 #include <rpc2/se.h>
-#include "sftp.h"
+#include <rpc2/sftp.h>
 
 
 /* sftp5.c */
